@@ -62,8 +62,10 @@ struct GpmIdlePrivate
 	guint		 timeout_sleep;		/* in seconds */
 	guint		 timeout_blank_id;
 	guint		 timeout_sleep_id;
-	gboolean	 x_idle;
-	gboolean	 check_type_cpu;
+    gboolean	 x_idle;
+    gboolean	 dim_idle;
+    gboolean	 control;
+    gboolean	 check_type_cpu;
 };
 
 enum {
@@ -101,11 +103,12 @@ static void
 gpm_idle_set_mode (GpmIdle *idle, GpmIdleMode mode)
 {
 	g_return_if_fail (GPM_IS_IDLE (idle));
-
-	if (mode != idle->priv->mode) {
+    //egg_debug ("Doing a state transition: %s", gpm_idle_mode_to_string (mode));
+    if (mode != idle->priv->mode) {
 		idle->priv->mode = mode;
-		egg_debug ("Doing a state transition: %s", gpm_idle_mode_to_string (mode));
-		g_signal_emit (idle, signals [IDLE_CHANGED], 0, mode);
+        //egg_debug ("Doing a state transition: %s", gpm_idle_mode_to_string (mode));
+        //egg_debug ("done a state transition: %s", gpm_idle_mode_to_string (mode));
+        g_signal_emit (idle, signals [IDLE_CHANGED], 0, mode);
 	}
 }
 
@@ -118,7 +121,7 @@ void
 gpm_idle_set_check_cpu (GpmIdle *idle, gboolean check_type_cpu)
 {
 	g_return_if_fail (GPM_IS_IDLE (idle));
-	egg_debug ("Setting the CPU load check to %i", check_type_cpu);
+	//egg_debug ("Setting the CPU load check to %i", check_type_cpu);
 	idle->priv->check_type_cpu = check_type_cpu;
 }
 
@@ -139,8 +142,9 @@ static gboolean
 gpm_idle_blank_cb (GpmIdle *idle)
 {
 	if (idle->priv->mode > GPM_IDLE_MODE_BLANK) {
-		egg_debug ("ignoring current mode %s", gpm_idle_mode_to_string (idle->priv->mode));
-		return FALSE;
+        //egg_debug ("ignoring current mode %s", gpm_idle_mode_to_string (idle->priv->mode));
+        //egg_debug ("ignoring current mode %s", gpm_idle_mode_to_string (idle->priv->mode));
+        return FALSE;
 	}
 	gpm_idle_set_mode (idle, GPM_IDLE_MODE_BLANK);
 	return FALSE;
@@ -176,27 +180,20 @@ out:
 static void
 gpm_idle_evaluate (GpmIdle *idle)
 {
-	gboolean is_idle;
-	gboolean is_idle_inhibited;
+    gboolean is_lock;
+    gboolean is_idle;
+    gboolean is_idle_inhibited;
 	gboolean is_suspend_inhibited;
 
+    is_lock = gpm_session_get_lock (idle->priv->session);
 	is_idle = gpm_session_get_idle (idle->priv->session);
 	is_idle_inhibited = gpm_session_get_idle_inhibited (idle->priv->session);
 	is_suspend_inhibited = gpm_session_get_suspend_inhibited (idle->priv->session);
-	egg_debug ("session_idle=%i, idle_inhibited=%i, suspend_inhibited=%i, x_idle=%i", is_idle, is_idle_inhibited, is_suspend_inhibited, idle->priv->x_idle);
-
-	/* check we are really idle */
-	if (!idle->priv->x_idle) {
+    egg_debug ("session_idle=%i, idle_inhibited=%i, suspend_inhibited=%i, x_idle=%i", is_idle, is_idle_inhibited, is_suspend_inhibited, idle->priv->x_idle);
+    /* check we are really idle */
+    if (!idle->priv->x_idle) {
 		gpm_idle_set_mode (idle, GPM_IDLE_MODE_NORMAL);
-		egg_debug ("X not idle");
-		if (idle->priv->timeout_blank_id != 0) {
-			g_source_remove (idle->priv->timeout_blank_id);
-			idle->priv->timeout_blank_id = 0;
-		}
-		if (idle->priv->timeout_sleep_id != 0) {
-			g_source_remove (idle->priv->timeout_sleep_id);
-			idle->priv->timeout_sleep_id = 0;
-		}
+        egg_debug ("X not idle");
 		goto out;
 	}
 
@@ -204,54 +201,91 @@ gpm_idle_evaluate (GpmIdle *idle)
 	if (is_idle_inhibited) {
 		egg_debug ("inhibited, so using normal state");
 		gpm_idle_set_mode (idle, GPM_IDLE_MODE_NORMAL);
-		if (idle->priv->timeout_blank_id != 0) {
-			g_source_remove (idle->priv->timeout_blank_id);
-			idle->priv->timeout_blank_id = 0;
-		}
-		if (idle->priv->timeout_sleep_id != 0) {
-			g_source_remove (idle->priv->timeout_sleep_id);
-			idle->priv->timeout_sleep_id = 0;
-		}
 		goto out;
 	}
 
 	/* normal to dim */
-	if (idle->priv->mode == GPM_IDLE_MODE_NORMAL) {
-		egg_debug ("normal to dim");
-		gpm_idle_set_mode (idle, GPM_IDLE_MODE_DIM);
-	}
-
-	/* set up blank callback even when session is not idle,
-	 * but only if we actually want to blank. */
-	if (idle->priv->timeout_blank_id == 0 &&
-	    idle->priv->timeout_blank != 0 && is_idle) {
-		egg_debug ("setting up blank callback for %is", idle->priv->timeout_blank);
-		idle->priv->timeout_blank_id = g_timeout_add_seconds (idle->priv->timeout_blank,
-								      (GSourceFunc) gpm_idle_blank_cb, idle);
-		g_source_set_name_by_id (idle->priv->timeout_blank_id, "[GpmIdle] blank");
-	}
-
-	/* are we inhibited from sleeping */
-	if (is_suspend_inhibited) {
-		egg_debug ("suspend inhibited");
-		if (idle->priv->timeout_sleep_id != 0) {
-			g_source_remove (idle->priv->timeout_sleep_id);
-			idle->priv->timeout_sleep_id = 0;
-		}
-	} else if (is_idle) {
-	/* only do the sleep timeout when the session is idle and we aren't inhibited from sleeping */
-		if (idle->priv->timeout_sleep_id == 0 &&
-		    idle->priv->timeout_sleep != 0) {
-			egg_debug ("setting up sleep callback %is", idle->priv->timeout_sleep);
-			idle->priv->timeout_sleep_id = g_timeout_add_seconds (idle->priv->timeout_sleep,
-									      (GSourceFunc) gpm_idle_sleep_cb, idle);
-			g_source_set_name_by_id (idle->priv->timeout_sleep_id, "[GpmIdle] sleep");
-		}
+    if (idle->priv->mode == GPM_IDLE_MODE_NORMAL && idle->priv->dim_idle) {
+        egg_debug ("normal to dim");
+        gpm_idle_set_mode (idle, GPM_IDLE_MODE_DIM);
 	}
 out:
 	return;
 }
 
+static void
+gpm_idle_control (GpmIdle *idle)
+{
+    gboolean is_lock;
+    gboolean is_idle;
+    gboolean is_idle_inhibited;
+    gboolean is_suspend_inhibited;
+
+    is_idle_inhibited = gpm_session_get_idle_inhibited (idle->priv->session);
+    is_suspend_inhibited = gpm_session_get_suspend_inhibited (idle->priv->session);
+    egg_debug ("session_idle=%i, idle_inhibited=%i, suspend_inhibited=%i, x_idle=%i", is_idle, is_idle_inhibited, is_suspend_inhibited, idle->priv->x_idle);
+    /* check we are really idle */
+    if (!idle->priv->control) {
+        //egg_debug ("ccX not idle");
+        if (idle->priv->timeout_blank_id != 0) {
+            g_source_remove (idle->priv->timeout_blank_id);
+            idle->priv->timeout_blank_id = 0;
+        }
+        if (idle->priv->timeout_sleep_id != 0) {
+            g_source_remove (idle->priv->timeout_sleep_id);
+            idle->priv->timeout_sleep_id = 0;
+        }
+        goto out;
+    }
+
+    /* are we inhibited from going idle */
+    if (is_idle_inhibited) {
+        egg_debug ("inhibited, so using normal state");
+        if (idle->priv->timeout_blank_id != 0) {
+            g_source_remove (idle->priv->timeout_blank_id);
+            idle->priv->timeout_blank_id = 0;
+        }
+        if (idle->priv->timeout_sleep_id != 0) {
+            g_source_remove (idle->priv->timeout_sleep_id);
+            idle->priv->timeout_sleep_id = 0;
+        }
+        goto out;
+    }
+
+    /* set up blank callback even when session is not idle,
+     * but only if we actually want to blank. */
+    if (idle->priv->timeout_blank_id == 0 &&
+        idle->priv->timeout_blank != 0 ) {
+        guint timeout_blank = idle->priv->timeout_blank - 60;
+        if (timeout_blank <= 0) timeout_blank = 1;
+        idle->priv->timeout_blank_id = g_timeout_add_seconds (timeout_blank,
+                                      (GSourceFunc) gpm_idle_blank_cb, idle);
+        g_source_set_name_by_id (idle->priv->timeout_blank_id, "[GpmIdle] blank");
+    }
+
+    /* are we inhibited from sleeping */
+    if (is_suspend_inhibited) {
+        //egg_debug ("ccsuspend inhibited");
+        if (idle->priv->timeout_sleep_id != 0) {
+            g_source_remove (idle->priv->timeout_sleep_id);
+            idle->priv->timeout_sleep_id = 0;
+        }
+    } else {
+    /* only do the sleep timeout when the session is idle and we aren't inhibited from sleeping */
+        if (idle->priv->timeout_sleep_id == 0 &&
+            idle->priv->timeout_sleep != 0) {
+            guint timeout_sleep = idle->priv->timeout_sleep - 60;
+            if(timeout_sleep <= 0)  timeout_sleep = 1;
+            idle->priv->timeout_sleep_id = g_timeout_add_seconds (timeout_sleep,
+                                          (GSourceFunc) gpm_idle_sleep_cb, idle);
+            g_source_set_name_by_id (idle->priv->timeout_sleep_id, "[GpmIdle] sleep");
+        }
+    }
+
+out:
+    return;
+}
+
 /**
  *  gpm_idle_adjust_timeout_dim:
  *  @idle_time: The new timeout we want to set, in seconds.
@@ -320,10 +354,13 @@ gpm_idle_set_timeout_blank (GpmIdle *idle, guint timeout)
 {
 	g_return_val_if_fail (GPM_IS_IDLE (idle), FALSE);
 
-	egg_debug ("Setting blank idle timeout: %ds", timeout);
-	if (idle->priv->timeout_blank != timeout) {
+//    //egg_debug ("Setting blank idle timeout: %ds", timeout);
+    //egg_debug ("Setting blank idle timeout: %ds", timeout);
+    if (idle->priv->timeout_blank != timeout) {
 		idle->priv->timeout_blank = timeout;
-		gpm_idle_evaluate (idle);
+//		gpm_idle_evaluate (idle);
+        gpm_idle_control (idle);
+
 	}
 	return TRUE;
 }
@@ -337,11 +374,13 @@ gpm_idle_set_timeout_sleep (GpmIdle *idle, guint timeout)
 {
 	g_return_val_if_fail (GPM_IS_IDLE (idle), FALSE);
 
-	egg_debug ("Setting sleep idle timeout: %ds", timeout);
-	if (idle->priv->timeout_sleep != timeout) {
+    //egg_debug ("Setting sleep idle timeout: %ds", timeout);
+    //egg_debug ("Setting sleep idle timeout: %ds", timeout);
+    if (idle->priv->timeout_sleep != timeout) {
 		idle->priv->timeout_sleep = timeout;
-		gpm_idle_evaluate (idle);
-	}
+//        gpm_idle_evaluate (idle);
+        gpm_idle_control (idle);
+    }
 	return TRUE;
 }
 
@@ -354,11 +393,20 @@ gpm_idle_set_timeout_sleep (GpmIdle *idle, guint timeout)
 static void
 gpm_idle_session_idle_changed_cb (GpmSession *session, gboolean is_idle, GpmIdle *idle)
 {
-	egg_debug ("Received ukui session idle changed: %i", is_idle);
-	idle->priv->x_idle = is_idle;
+    egg_debug ("Received ukui session idle changed: %i", is_idle);
+    idle->priv->x_idle = is_idle;
 	gpm_idle_evaluate (idle);
 }
 
+static void
+gpm_idle_session_control_changed_cb (GpmSession *session, gboolean is_idle, GpmIdle *idle)
+{
+    egg_debug ("Received ukui session control changed: %i", is_idle);
+    idle->priv->control = is_idle;
+    gpm_idle_control (idle);
+}
+
+
 /**
  * gpm_idle_session_inhibited_changed_cb:
  **/
@@ -366,7 +414,9 @@ static void
 gpm_idle_session_inhibited_changed_cb (GpmSession *session, gboolean is_idle_inhibited, gboolean is_suspend_inhibited, GpmIdle *idle)
 {
 	egg_debug ("Received ukui session inhibited changed: idle=(%i), suspend=(%i)", is_idle_inhibited, is_suspend_inhibited);
-	gpm_idle_evaluate (idle);
+//	gpm_idle_evaluate (idle);
+    gpm_idle_control (idle);
+
 }
 
 /**
@@ -377,11 +427,13 @@ gpm_idle_session_inhibited_changed_cb (GpmSession *session, gboolean is_idle_inh
 static void
 gpm_idle_idletime_alarm_expired_cb (EggIdletime *idletime, guint alarm_id, GpmIdle *idle)
 {
-	egg_debug ("idletime alarm: %i", alarm_id);
+    egg_debug ("idletime alarm: %i", alarm_id);
+    //egg_debug ("idletime alarm: %i", alarm_id);
 
 	/* set again */
-	idle->priv->x_idle = TRUE;
-	gpm_idle_evaluate (idle);
+    idle->priv->x_idle = TRUE;
+    idle->priv->dim_idle = TRUE;
+    gpm_idle_evaluate (idle);
 }
 
 /**
@@ -392,10 +444,12 @@ gpm_idle_idletime_alarm_expired_cb (EggIdletime *idletime, guint alarm_id, GpmId
 static void
 gpm_idle_idletime_reset_cb (EggIdletime *idletime, GpmIdle *idle)
 {
-	egg_debug ("idletime reset");
+    //egg_debug ("idletime reset");
+    egg_debug ("idletime reset");
 
-	idle->priv->x_idle = FALSE;
-	gpm_idle_evaluate (idle);
+    idle->priv->x_idle = FALSE;
+    idle->priv->dim_idle = FALSE;
+    gpm_idle_evaluate (idle);
 }
 
 /**
@@ -472,11 +526,14 @@ gpm_idle_init (GpmIdle *idle)
 	idle->priv->timeout_sleep = G_MAXUINT;
 	idle->priv->timeout_blank_id = 0;
 	idle->priv->timeout_sleep_id = 0;
-	idle->priv->x_idle = FALSE;
-	idle->priv->load = gpm_load_new ();
+    idle->priv->x_idle = FALSE;
+    idle->priv->dim_idle = FALSE;
+    idle->priv->control = FALSE;
+    idle->priv->load = gpm_load_new ();
 	idle->priv->session = gpm_session_new ();
-	g_signal_connect (idle->priv->session, "idle-changed", G_CALLBACK (gpm_idle_session_idle_changed_cb), idle);
-	g_signal_connect (idle->priv->session, "inhibited-changed", G_CALLBACK (gpm_idle_session_inhibited_changed_cb), idle);
+    g_signal_connect (idle->priv->session, "idle-changed", G_CALLBACK (gpm_idle_session_idle_changed_cb), idle);
+    g_signal_connect (idle->priv->session, "control-changed", G_CALLBACK (gpm_idle_session_control_changed_cb), idle);
+    g_signal_connect (idle->priv->session, "inhibited-changed", G_CALLBACK (gpm_idle_session_inhibited_changed_cb), idle);
 
 	idle->priv->idletime = egg_idletime_new ();
 	g_signal_connect (idle->priv->idletime, "reset", G_CALLBACK (gpm_idle_idletime_reset_cb), idle);
