@@ -47,8 +47,10 @@ typedef enum {
 	GPM_SESSION_STATUS_ENUM_AVAILABLE = 0,
 	GPM_SESSION_STATUS_ENUM_INVISIBLE,
 	GPM_SESSION_STATUS_ENUM_BUSY,
-	GPM_SESSION_STATUS_ENUM_IDLE,
-	GPM_SESSION_STATUS_ENUM_UNKNOWN
+    GPM_SESSION_STATUS_ENUM_IDLE,
+    GPM_SESSION_STATUS_ENUM_PAD,
+    GPM_SESSION_STATUS_ENUM_IDLE_CONTROL,
+    GPM_SESSION_STATUS_ENUM_UNKNOWN
 } GpmSessionStatusEnum;
 
 typedef enum {
@@ -64,8 +66,9 @@ struct GpmSessionPrivate
 	GDBusProxy		*proxy_presence;
 	GDBusProxy		*proxy_client_private;
 	GDBusProxy		*proxy_prop;
-	gboolean		 is_idle_old;
-	gboolean		 is_idle_inhibited_old;
+    gboolean		 is_idle_old;
+    gboolean		 is_lock;
+    gboolean		 is_idle_inhibited_old;
 	gboolean		 is_suspend_inhibited_old;
 };
 
@@ -76,6 +79,7 @@ enum {
 	QUERY_END_SESSION,
 	END_SESSION,
 	CANCEL_END_SESSION,
+    CONTROL_CHANGED,
 	LAST_SIGNAL
 };
 
@@ -118,6 +122,16 @@ gpm_session_get_idle (GpmSession *session)
 	return session->priv->is_idle_old;
 }
 
+/**
+ * gpm_session_get_idle:
+ **/
+gboolean
+gpm_session_get_lock (GpmSession *session)
+{
+    g_return_val_if_fail (GPM_IS_SESSION (session), FALSE);
+    return session->priv->is_lock;
+}
+
 /**
  * gpm_session_get_idle_inhibited:
  **/
@@ -149,14 +163,43 @@ gpm_session_presence_status_changed_cb (GDBusProxy *proxy, gchar *sender_name, g
 	if(g_strcmp0(signal_name,"StatusChanged") == 0)
 	{
 		g_variant_get (parameters,"(u)",&status);
-		//g_message ("status======%d",status);	
+        //egg_debug ("status======%d",status);//530
 		gboolean is_idle;
-		is_idle = (status == GPM_SESSION_STATUS_ENUM_IDLE);
-		if (is_idle != session->priv->is_idle_old) {
-		egg_debug ("emitting idle-changed : (%i)", is_idle);
-		session->priv->is_idle_old = is_idle;
-		g_signal_emit (session, signals [IDLE_CHANGED], 0, is_idle);
+        gboolean control;
+        if (status == GPM_SESSION_STATUS_ENUM_IDLE)
+        {
+            is_idle = TRUE;
+//		if (is_idle != session->priv->is_idle_old) {
+
+            //egg_debug ("emitting idle-changed : (%i)", is_idle);
+            //egg_debug ("emitting idle-changed : (%i)", is_idle);
+//            session->priv->is_lock = (status == GPM_SESSION_STATUS_ENUM_IDLE);
+            session->priv->is_idle_old = is_idle;
+            g_signal_emit (session, signals [IDLE_CHANGED], 0, is_idle);
+        }
+        if (status == GPM_SESSION_STATUS_ENUM_AVAILABLE)
+        {
+            is_idle = FALSE;
+//		if (is_idle != session->priv->is_idle_old) {
+
+            //egg_debug ("emitting idle-changed : (%i)", is_idle);
+            //egg_debug ("emitting idle-changed : (%i)", is_idle);
+//            session->priv->is_lock = (status == GPM_SESSION_STATUS_ENUM_IDLE);
+            session->priv->is_idle_old = is_idle;
+            g_signal_emit (session, signals [IDLE_CHANGED], 0, is_idle);
 		}
+        //added by jh
+        if (status == GPM_SESSION_STATUS_ENUM_IDLE_CONTROL)
+        {
+            control = TRUE;
+            g_signal_emit (session, signals [CONTROL_CHANGED], 0, control);
+        }
+        if (status == GPM_SESSION_STATUS_ENUM_AVAILABLE)
+        {
+            control = FALSE;
+            g_signal_emit (session, signals [CONTROL_CHANGED], 0, control);
+        }
+
 	}
 }
 
@@ -194,7 +237,7 @@ gpm_session_is_idle (GpmSession *session)
         g_variant_get (u_cookie, "(u)", &tmp);
         g_variant_unref (u_cookie);
 
-	//g_message ("is idle============= %d",tmp);
+	////egg_debug ("is idle============= %d",tmp);
 	/* find out if this change altered the inhibited state */
 	/*ret = dbus_g_proxy_call (session->priv->proxy_prop, "Get", &error,
 				 G_TYPE_STRING, GPM_SESSION_MANAGER_PRESENCE_INTERFACE,
@@ -312,7 +355,7 @@ out:
 static void
 gpm_session_stop_cb (GDBusProxy *proxy, gchar *sender_name, gchar * signal_name, GVariant *parameters, gpointer user_data)
 {
-	egg_debug ("emitting ::stop()");
+	//egg_debug ("emitting ::stop()");
 	GpmSession *session = GPM_SESSION(user_data);
 	if(g_strcmp0(signal_name,"Stop") == 0) {
 		g_signal_emit (session, signals [STOP], 0);
@@ -328,7 +371,7 @@ gpm_session_query_end_session_cb (GDBusProxy *proxy, gchar *sender_name, gchar *
 	GpmSession *session = GPM_SESSION(user_data);
 	guint flags;
 	g_variant_get (parameters,"(u)",&flags);
-	egg_debug ("emitting ::query-end-session(%i)", flags);
+	//egg_debug ("emitting ::query-end-session(%i)", flags);
         if(g_strcmp0(signal_name,"QueryEndSession") == 0) {
 		g_signal_emit (session, signals [QUERY_END_SESSION], 0, flags);
         }
@@ -343,7 +386,7 @@ gpm_session_end_session_cb (GDBusProxy *proxy, gchar *sender_name, gchar * signa
         GpmSession *session = GPM_SESSION(user_data);
         guint flags;
         g_variant_get (parameters,"(u)",&flags);
-	egg_debug ("emitting ::end-session(%i)", flags);
+	//egg_debug ("emitting ::end-session(%i)", flags);
         if(g_strcmp0(signal_name,"EndSession") == 0) {
                 g_signal_emit (session, signals [END_SESSION], 0, flags);
         }
@@ -411,7 +454,7 @@ gpm_session_register_client (GpmSession *session, const gchar *app_id, const gch
 	/* no ukui-session */
 	if (session->priv->proxy == NULL) {
 		egg_warning ("no ukui-session");
-		g_message ("no ukui-session");
+		//egg_debug ("no ukui-session");
 		goto out;
 	}
 
@@ -437,7 +480,7 @@ gpm_session_register_client (GpmSession *session, const gchar *app_id, const gch
 
         if (u_cookie == NULL)
         {
-		egg_debug ("RegisterClient Wrong");
+		//egg_debug ("RegisterClient Wrong");
                 g_error_free (error);
                 return FALSE;
         }
@@ -476,8 +519,8 @@ gpm_session_register_client (GpmSession *session, const gchar *app_id, const gch
 	/* get EndSession */
 
 	g_signal_connect (session->priv->proxy_client_private, "EndSession", G_CALLBACK (gpm_session_end_session_cb), session);
-	//egg_debug ("registered startup '%s' to client id '%s'", client_startup_id, client_id);
-	//g_message ("registered startup '%s' to client id '%s'", client_startup_id, client_id);
+	////egg_debug ("registered startup '%s' to client id '%s'", client_startup_id, client_id);
+	////egg_debug ("registered startup '%s' to client id '%s'", client_startup_id, client_id);
 out:
 	if (client_id)
 		g_free (client_id);
@@ -498,7 +541,7 @@ gpm_session_inhibit_changed_cb (GDBusProxy *proxy, gchar *sender_name, gchar * s
 		is_idle_inhibited = gpm_session_is_idle_inhibited (session);
 		is_suspend_inhibited = gpm_session_is_suspend_inhibited (session);
 		if (is_idle_inhibited != session->priv->is_idle_inhibited_old || is_suspend_inhibited != session->priv->is_suspend_inhibited_old) {
-			egg_debug ("emitting inhibited-changed : idle=(%i), suspend=(%i)", is_idle_inhibited, is_suspend_inhibited);
+			//egg_debug ("emitting inhibited-changed : idle=(%i), suspend=(%i)", is_idle_inhibited, is_suspend_inhibited);
 			session->priv->is_idle_inhibited_old = is_idle_inhibited;
 			session->priv->is_suspend_inhibited_old = is_suspend_inhibited;
 			g_signal_emit (session, signals [INHIBITED_CHANGED], 0, is_idle_inhibited, is_suspend_inhibited);
@@ -559,6 +602,13 @@ gpm_session_class_init (GpmSessionClass *klass)
 			      G_STRUCT_OFFSET (GpmSessionClass, cancel_end_session),
 			      NULL, NULL, g_cclosure_marshal_VOID__VOID,
 			      G_TYPE_NONE, 0);
+    signals [CONTROL_CHANGED] =
+        g_signal_new ("control-changed",
+                  G_TYPE_FROM_CLASS (object_class),
+                  G_SIGNAL_RUN_LAST,
+                  G_STRUCT_OFFSET (GpmSessionClass, control_changed),
+                  NULL, NULL, g_cclosure_marshal_VOID__BOOLEAN,
+                  G_TYPE_NONE, 1, G_TYPE_BOOLEAN);
 }
 
 /**
@@ -572,8 +622,9 @@ gpm_session_init (GpmSession *session)
 	GError *error = NULL;
 
 	session->priv = GPM_SESSION_GET_PRIVATE (session);
-	session->priv->is_idle_old = FALSE;
-	session->priv->is_idle_inhibited_old = FALSE;
+    session->priv->is_idle_old = FALSE;
+    session->priv->is_lock = FALSE;
+    session->priv->is_idle_inhibited_old = FALSE;
 	session->priv->is_suspend_inhibited_old = FALSE;
 	session->priv->proxy_client_private = NULL;
 
@@ -643,7 +694,7 @@ gpm_session_init (GpmSession *session)
 	session->priv->is_idle_inhibited_old = gpm_session_is_idle_inhibited (session);
 	session->priv->is_suspend_inhibited_old = gpm_session_is_suspend_inhibited (session);
 	session->priv->is_idle_old = gpm_session_is_idle (session);
-	egg_debug ("idle: %i, idle_inhibited: %i, suspend_inhibited: %i", session->priv->is_idle_old, session->priv->is_idle_inhibited_old, session->priv->is_suspend_inhibited_old);
+	//egg_debug ("idle: %i, idle_inhibited: %i, suspend_inhibited: %i", session->priv->is_idle_old, session->priv->is_idle_inhibited_old, session->priv->is_suspend_inhibited_old);
 }
 
 /**
