@@ -475,7 +475,7 @@ draw_volume_boxes (MsdMediaKeysWindow *window,
         cairo_fill (cr);*/
 
 	cairo_save(cr);
-	cairo_set_source_rgba(cr, 0, 0, 0, 0.2);
+    cairo_set_source_rgba(cr, 1, 1, 1, 0.2);
 	msd_osd_window_draw_rounded_rectangle (cr, 1.0, 29, 32, 3, bar_width, 200);
         cairo_fill (cr);
 	cairo_restore (cr);
@@ -584,7 +584,7 @@ draw_action_volume (MsdMediaKeysWindow *window,
                 speaker_cy = icon_box_y0 + speaker_height / 2;
 
 #if 0
-                g_message ("speaker box: w=%f h=%f cx=%f cy=%f",
+                //egg_debug ("speaker box: w=%f h=%f cx=%f cy=%f",
                            speaker_width,
                            speaker_height,
                            speaker_cx,
@@ -618,7 +618,6 @@ draw_action_volume (MsdMediaKeysWindow *window,
                         draw_cross (cr, cross_x0, cross_y0, cross_size);
                 }
         }
-
         /* draw volume meter */
         draw_volume_boxes (window,
                            cr,
@@ -701,12 +700,12 @@ draw_action_custom (MsdMediaKeysWindow *window,
         bright_box_y0 = round (icon_box_height + icon_box_y0);
 
 #if 0
-        g_message ("icon box: w=%f h=%f _x0=%f _y0=%f",
+        //egg_debug ("icon box: w=%f h=%f _x0=%f _y0=%f",
                    icon_box_width,
                    icon_box_height,
                    icon_box_x0,
                    icon_box_y0);
-        g_message ("brightness box: w=%f h=%f _x0=%f _y0=%f",
+        //egg_debug ("brightness box: w=%f h=%f _x0=%f _y0=%f",
                    bright_box_width,
                    bright_box_height,
                    bright_box_x0,
