@@ -33,8 +33,6 @@
 /* schema location */
 #define GPM_SETTINGS_SCHEMA		"org.ukui.power-manager"
 #define GPM_SETTINGS_KEY_POLICY         "icon-policy"
-#define GPM_SETTINGS_SCHEMA_STYLE		"org.ukui.style"
-#define GPM_SETTINGS_STYLE_NAME        "style-name"
 
 /* actions */
 #define GPM_SETTINGS_ACTION_CRITICAL_UPS		"action-critical-ups"
@@ -54,6 +52,7 @@
 #define GPM_SETTINGS_IDLE_DIM_BATT			"idle-dim-battery"
 #define GPM_SETTINGS_IDLE_DIM_TIME			"idle-dim-time"
 #define GPM_SETTINGS_BRIGHTNESS_AC			"brightness-ac"
+#define GPM_SETTINGS_BRIGHTNESS_BAT			"brightness-bat"
 #define GPM_SETTINGS_BRIGHTNESS_DIM_BATT		"brightness-dim-battery"
 
 /* keyboard backlight */
@@ -82,6 +81,11 @@
 #define GPM_SETTINGS_NOTIFY_SLEEP_FAILED		"notify-sleep-failed"
 #define GPM_SETTINGS_NOTIFY_SLEEP_FAILED_URI		"notify-sleep-failed-uri"
 #define GPM_SETTINGS_NOTIFY_LOW_POWER			"notify-low-power"
+#define GPM_SETTINGS_BAT_POLICY                         "power-policy-battery"
+#define GPM_SETTINGS_ON_BAT_AUTO_SAVE                           "on-battery-auto-save"
+#define GPM_SETTINGS_LOW_BAT_AUTO_SAVE                          "low-battery-auto-save"
+#define GPM_SETTINGS_DISPLAY_LEFT_TIME                          "dispaly-left-time-of-charge-and-discharge"
+
 
 /* thresholds */
 #define GPM_SETTINGS_PERCENTAGE_LOW			"percentage-low"
