@@ -23,13 +23,10 @@
 #include <QDBusInterface>
 #include <QDebug>
 
-#include "engine_common.h"
-
 EngineDevice* EngineDevice::instance = NULL;
 
 void EngineDevice::power_device_get_devices()
 {
-
     QList<QDBusObjectPath> deviceNames;
 
     /* call enum dbus*/
@@ -45,6 +42,7 @@ void EngineDevice::power_device_get_devices()
     else {
     }
     int len = deviceNames.size();
+    //qDebug()<<deviceNames.at(1).path();
     for(int i = 0; i < len; i++)
     {
         DEVICE *device = new DEVICE;
@@ -61,7 +59,6 @@ void EngineDevice::power_device_get_devices()
 
 }
 
-
 EngineDevice::EngineDevice(QObject *parent) : QObject(parent)
 {
     icon_policy = GPM_ICON_POLICY_PRESENT;
@@ -74,6 +71,13 @@ EngineDevice::EngineDevice(QObject *parent) : QObject(parent)
     settings = new QGSettings(GPM_SETTINGS_SCHEMA);
     connect(settings,SIGNAL(changed(const QString&)),this,SLOT(engine_policy_settings_cb(const QString&)));
 
+    low_percentage = settings->get(GPM_SETTINGS_PERCENTAGE_LOW).toInt();
+    critical_percentage = settings->get(GPM_SETTINGS_PERCENTAGE_CRITICAL).toInt();
+    action_percentage = settings->get(GPM_SETTINGS_PERCENTAGE_ACTION).toInt();
+    if (action_percentage >= critical_percentage)
+    {
+        action_percentage = critical_percentage - 1;
+    }
 }
 
 void EngineDevice::engine_policy_settings_cb(const QString& str)
@@ -114,7 +118,7 @@ void EngineDevice::power_device_add(QDBusObjectPath msg)
         dbusArg >> map;
         UpDeviceKind kind = (UpDeviceKind)map.value("Type").toInt();
 
-        if(kind != UP_DEVICE_KIND_LINE_POWER && kind != UP_DEVICE_KIND_BATTERY && kind != UP_DEVICE_KIND_PHONE && kind != UP_DEVICE_KIND_COMPUTER)
+        if(kind != UP_DEVICE_KIND_LINE_POWER && kind != UP_DEVICE_KIND_BATTERY)
             return;
 
         DEVICE *dev = new DEVICE;
@@ -164,13 +168,11 @@ void EngineDevice::power_device_remove(QDBusObjectPath msg)
             break;
         }
     }
-
 }
 
 
 void EngineDevice::getProperty(QString path,DEV& dev)
 {
-
     QDBusMessage msg = QDBusMessage::createMethodCall(DBUS_SERVICE,path,
             DBUS_INTERFACE_PRO,"GetAll");
     msg << DBUS_INTERFACE_DEV;
@@ -204,7 +206,6 @@ void EngineDevice::getProperty(QString path,DEV& dev)
         dev.TimeToEmpty = map.value(QString("TimeToEmpty")).toLongLong();
         dev.TimeToFull = map.value(QString("TimeToFull")).toLongLong();
         dev.Voltage = QString::number(map.value(QString("Voltage")).toDouble(), 'f', 1) + " V";
-
     }
 }
 
@@ -236,7 +237,7 @@ void EngineDevice::putAttributes(QMap<QString,QVariant>& map,DEV &btrDetailData)
     if(map.contains("State"))
     {
         btrDetailData.State = (UpDeviceState)map.value(QString("State")).toInt();
-        //qDebug()<< "state:" << btrDetailData.State;
+        ////qDebug()<< "state:" << btrDetailData.State;
     }
     if(map.contains("Percentage"))
     {
@@ -255,7 +256,9 @@ void EngineDevice::power_device_change_callback(QDBusMessage msg,QString path)
 {
     /* if battery change to display devices */
     /* judge state */
-
+    static bool init_level = true;
+    static UpDeviceLevel  level_old;
+    UpDeviceLevel  level;
     DEVICE *item = nullptr;
     Q_FOREACH (auto item_tmp, devices)
     {
@@ -274,34 +277,51 @@ void EngineDevice::power_device_change_callback(QDBusMessage msg,QString path)
     arg >> map;
     putAttributes(map,item->m_dev);
     Q_EMIT signal_device_change(item);
+
+    if ((item->m_dev.kind != UP_DEVICE_KIND_BATTERY) && (item->m_dev.kind != UP_DEVICE_KIND_UPS))
+            return;
     if(item->m_dev.State != tmp_dev.State)
     {
         if(item->m_dev.State==UP_DEVICE_STATE_DISCHARGING)
         {
-            Q_EMIT engine_signal_discharge(tmp_dev);
+            Q_EMIT engine_signal_discharge(item->m_dev);
         }
         else if (item->m_dev.State==UP_DEVICE_STATE_FULLY_CHARGED)
         {
-            Q_EMIT engine_signal_fullycharge(tmp_dev);
+            Q_EMIT engine_signal_fullycharge(item->m_dev);
+        }
+        else if (item->m_dev.State==UP_DEVICE_STATE_CHARGING)
+        {
+            Q_EMIT engine_signal_charge(item->m_dev);
         }
         //save new state
     }
-    /* check the warning state has not changed */
-    if(item->m_dev.warnlevel != tmp_dev.warnlevel)
+    level = engine_get_warning (item->m_dev);
+
+    if (init_level)
     {
-        if(item->m_dev.warnlevel==UP_DEVICE_LEVEL_LOW)
+        level_old = level;
+        init_level = false;
+    }
+    /* check the warning state has not changed */
+    if(level != level_old)
+    {
+        if(level==UP_DEVICE_LEVEL_LOW)
         {
-            Q_EMIT engine_signal_charge_low(tmp_dev);
+		//理论上connect一个dbus，但是代码如狗屎一般，看到这个注释的你好自为之。
+	    int save = settings->get(GPM_SETTINGS_LOW_BAT_AUTO_SAVE).toInt();
+	    if(save)settings->set(GPM_SETTINGS_BAT_POLICY,1);
+            Q_EMIT engine_signal_charge_low(item->m_dev);
         }
-        else if (item->m_dev.warnlevel==UP_DEVICE_LEVEL_CRITICAL)
+        else if (level==UP_DEVICE_LEVEL_CRITICAL)
         {
-            Q_EMIT engine_signal_charge_critical(tmp_dev);
+            Q_EMIT engine_signal_charge_critical(item->m_dev);
         }
-        else if(item->m_dev.warnlevel==UP_DEVICE_LEVEL_ACTION)
+        else if(level==UP_DEVICE_LEVEL_ACTION)
         {
-            Q_EMIT engine_signal_charge_action(tmp_dev);
+            Q_EMIT engine_signal_charge_action(item->m_dev);
         }
-        //save new warning;
+        level_old = level;
     }
 
     /*recaculate state*/
@@ -310,7 +330,6 @@ void EngineDevice::power_device_change_callback(QDBusMessage msg,QString path)
 
 void EngineDevice::power_device_recalculate_state()
 {
-
     /*recaculate icon*/
     power_device_recalculate_icon();
     /*recaculate sum*/
@@ -385,7 +404,6 @@ QString EngineDevice::power_device_get_icon()
         }
     }
 
-
     /* we try GPM_ENGINE_WARNING_LOW: BATTERY, UPS, MOUSE, KEYBOARD */
     if (icon_policy == GPM_ICON_POLICY_LOW || icon_policy == GPM_ICON_POLICY_ALWAYS)
     {
@@ -499,22 +517,68 @@ QString EngineDevice::power_device_get_icon_exact (UpDeviceKind device_kind, UpD
 bool EngineDevice::engine_recalculate_summary ()
 {
     QString summary;
+    QStringList Battery_State;
 
+    Battery_State = engine_get_state();
     summary = engine_get_summary ();
     if (previous_summary.isNull()) {
         previous_summary = summary;
         Q_EMIT engine_signal_summary_change(summary);
+        Q_EMIT engine_signal_Battery_State(Battery_State);
         return true;
     }
 
     if (previous_summary != summary) {
         previous_summary = summary;
         Q_EMIT engine_signal_summary_change(summary);
+        Q_EMIT engine_signal_Battery_State(Battery_State);
         return true;
     }
     return false;
 }
 
+QStringList EngineDevice::engine_get_state()
+{
+    DEVICE *device;
+    UpDeviceState state;
+    QStringList tooltip;
+    QStringList part;
+    bool is_present;
+    UpDeviceKind kind;
+
+    Q_FOREACH (device, devices) {
+        is_present = device->m_dev.IsPresent;
+        state = device->m_dev.State;
+        kind = device->m_dev.kind;
+        if ((!is_present)||(kind != UP_DEVICE_KIND_BATTERY))
+            continue;
+        if (state == UP_DEVICE_STATE_EMPTY)
+            continue;
+        part = engine_get_Battery_State (device);
+        if (!part.isEmpty())
+            tooltip.append(part);
+    }
+    return tooltip;
+}
+
+QStringList EngineDevice::engine_get_Battery_State(DEVICE* dv)
+{
+    UpDeviceState state;
+    double percentage;
+    QStringList result;
+    state = dv->m_dev.State;
+    int EMPTY = dv->m_dev.TimeToEmpty;
+    percentage = dv->m_dev.Percentage;
+    bool is_present;
+    is_present = dv->m_dev.IsPresent;
+    if (!is_present)
+        return result;
+    result.append(QString("%1").arg(percentage));
+    result.append(QString("%1").arg(state));
+    result.append(QString("%1").arg(EMPTY));
+    return result;
+}
+
 /**
  * engine_get_summary:
  *
@@ -614,7 +678,6 @@ QString EngineDevice::engine_get_device_predict(DEVICE* dv)
     QString kind_desc;
     uint time_to_full_round;
     uint time_to_empty_round;
-//    QString time_to_full_str;
     QString time_to_empty_str;
     UpDeviceKind kind;
     UpDeviceState state;
@@ -706,12 +769,26 @@ QString EngineDevice::engine_get_device_predict(DEVICE* dv)
         result = QString("%1(%2%)").arg(kind_desc).arg(percentage);
     }
     return result;
-    qDebug ()<< "result:" << result;
 }
 
 /**
  * engine_get_device_summary:
  **/
+int EngineDevice::hours(int value)
+{
+    int second;
+    int hour;
+    hour = second/3600;
+    return hour;
+}
+int EngineDevice::minutes(int value)
+{
+    int second;
+    int minute;
+    minute = (second%3600)/60;
+    return minute;
+}
+
 QString EngineDevice::engine_get_device_summary(DEVICE* dv)
 {
     QString kind_desc;
@@ -746,11 +823,16 @@ QString EngineDevice::engine_get_device_summary(DEVICE* dv)
 
     } else if (state == UP_DEVICE_STATE_DISCHARGING) {
 
-        result = tr("%1% available, not charging").arg(percentage);
+        result = tr("Left %1h %2m (%3%)").arg(hours(time_to_empty)).arg(minutes(time_to_empty)).arg(percentage);
 
     } else if (state == UP_DEVICE_STATE_CHARGING) {
-
-        result = tr("%1% available, charging").arg(percentage);
+	    //需要connect一个dbus才对，可以但没必要，因为我觉得这个需求很扯
+	int is_show = settings->get(GPM_SETTINGS_DISPLAY_LEFT_TIME).toInt();
+	if(is_show){
+        result = tr("Left %1h %2m to full").arg(hours(time_to_full)).arg(minutes(time_to_full));
+	}else{
+        	result = tr("charging (%1%)").arg(percentage);
+	}
 
     } else if (state == UP_DEVICE_STATE_PENDING_DISCHARGE) {
 
@@ -951,7 +1033,14 @@ QString EngineDevice::engine_get_device_icon (DEVICE *device)
 
         } else if (state == UP_DEVICE_STATE_FULLY_CHARGED) {
             /* battery-full-charged-symbolic */
-            result = QString ("%1-full-charged-symbolic").arg(prefix);
+		            /* battery-full-charged-symbolic */
+         //   result = QString("%1-full-charged-symbolic").arg(prefix);
+          index_str = engine_get_device_icon_index(percentage);
+            /* battery-level-percent-charging-symbolic */
+            result =
+                QString("%1-level-%2-charging-symbolic").arg(prefix).
+                arg(index_str);
+            //result = QString ("%1-full-charged-symbolic").arg(prefix);
         } else if (state == UP_DEVICE_STATE_CHARGING) {
             index_str = engine_get_device_icon_index (percentage);
             /* battery-level-percent-charging-symbolic */
@@ -1124,3 +1213,56 @@ QString EngineDevice::engine_get_state_text (UpDeviceState state)
     }
     return  state_text;
 }
+
+/**
+ * engine_get_warning_percentage:
+ **/
+UpDeviceLevel EngineDevice::engine_get_warning_percentage (DEV dev)
+{
+    int percentage;
+
+    /* get device properties */
+    percentage = dev.Percentage;
+    if (percentage <= action_percentage)
+        return UP_DEVICE_LEVEL_ACTION;
+    if (percentage <= critical_percentage || percentage <= 10)
+        return UP_DEVICE_LEVEL_CRITICAL;
+    if (percentage <= low_percentage)
+        return UP_DEVICE_LEVEL_LOW;
+    return UP_DEVICE_LEVEL_NONE;
+}
+
+/**
+ * engine_get_warning:
+ *
+ **/
+UpDeviceLevel EngineDevice::engine_get_warning (DEV dev)
+{
+    UpDeviceKind kind;
+    UpDeviceState state;
+    UpDeviceLevel warning_type;
+
+    /* get device properties */
+    kind = dev.kind;
+    state = dev.State;
+
+    /* default to no engine */
+    warning_type = UP_DEVICE_LEVEL_NONE;
+
+    /* if the device in question is on ac, don't give a warning */
+    if (state == UP_DEVICE_STATE_CHARGING)
+        goto out;
+
+    if (kind == UP_DEVICE_KIND_BATTERY || kind == UP_DEVICE_KIND_UPS) {
+        warning_type = engine_get_warning_percentage (dev);
+    }
+
+    /* If we have no important engines, we should test for discharging */
+    if (warning_type == UP_DEVICE_LEVEL_NONE) {
+        if (state == UP_DEVICE_STATE_DISCHARGING)
+            warning_type = UP_DEVICE_LEVEL_DISCHARGING;
+    }
+
+ out:
+    return warning_type;
+}
